@@ -414,13 +414,17 @@ class Consumer(object):
             reached.
 
         """
+        self.consume(no_ack=no_ack)
+        return self.backend.consume(limit=limit)
+
+    def consume(self, no_ack=None):
+        """Declare consumer."""
         no_ack = no_ack or self.no_ack
         self.backend.declare_consumer(queue=self.queue, no_ack=no_ack,
                                       callback=self._receive_callback,
                                       consumer_tag=self.consumer_tag,
                                       nowait=True)
         self.channel_open = True
-        return self.backend.consume(limit=limit)
 
     def wait(self, limit=None):
         """Go into consume mode.
@@ -568,9 +572,9 @@ class Publisher(object):
         The default delivery mode used for messages. The value is an integer.
         The following delivery modes are supported by (at least) RabbitMQ:
 
-            * 1 or "non-persistent"
+            * 1 or "transient"
 
-                The message is non-persistent. Which means it is stored in
+                The message is transient. Which means it is stored in
                 memory only, and is lost if the server dies or restarts.
 
             * 2 or "persistent"
@@ -612,10 +616,12 @@ class Publisher(object):
     """
 
     NONE_PERSISTENT_DELIVERY_MODE = 1
+    TRANSIENT_DELIVERY_MODE = 1
     PERSISTENT_DELIVERY_MODE = 2
     DELIVERY_MODES = {
-            "non-persistent": NONE_PERSISTENT_DELIVERY_MODE,
+            "transient": TRANSIENT_DELIVERY_MODE,
             "persistent": PERSISTENT_DELIVERY_MODE,
+            "non-persistent": TRANSIENT_DELIVERY_MODE,
     }
 
     exchange = ""
@@ -872,7 +878,7 @@ class ConsumerSet(object):
         self.connection = connection
         self.options = options
         self.from_dict = from_dict or {}
-        self.consumers = consumers or []
+        self.consumers = []
         self.callbacks = callbacks or []
         self._open_consumers = []
 
@@ -880,6 +886,9 @@ class ConsumerSet(object):
 
         self.auto_ack = options.get("auto_ack", self.auto_ack)
 
+        if consumers:
+            [self.add_consumer(consumer) for consumer in consumers]
+
         [self.add_consumer_from_dict(queue_name, **queue_options)
                 for queue_name, queue_options in self.from_dict.items()]
 
@@ -928,17 +937,20 @@ class ConsumerSet(object):
                                       consumer_tag=consumer.consumer_tag)
         self._open_consumers.append(consumer.consumer_tag)
 
-    def iterconsume(self, limit=None):
-        """Cycle between all consumers in consume mode.
-
-        See :meth:`Consumer.iterconsume`.
-        """
+    def consume(self):
+        """Declare consumers."""
         head = self.consumers[:-1]
         tail = self.consumers[-1]
         [self._declare_consumer(consumer, nowait=True)
                 for consumer in head]
         self._declare_consumer(tail, nowait=False)
 
+    def iterconsume(self, limit=None):
+        """Cycle between all consumers in consume mode.
+
+        See :meth:`Consumer.iterconsume`.
+        """
+        self.consume()
         return self.backend.consume(limit=limit)
 
     def discard_all(self):
